@@ -4,6 +4,7 @@ import numpy as np
 import copy
 
 from autoconf import conf
+from autoarray.structures import abstract_structure
 from autoarray.structures import arrays
 from autoarray.structures import grids
 from autoarray.mask import mask_2d as msk
@@ -33,18 +34,20 @@ def grid_from_mask_and_grid_class(
 
 
 class AbstractDataset:
-    def __init__(self, data, noise_map, positions=None, name=None):
+    def __init__(
+        self,
+        data: abstract_structure.AbstractStructure,
+        noise_map: abstract_structure.AbstractStructure,
+        positions: grids.GridCoordinates = None,
+        name: str = None,
+    ):
         """A collection of abstract 2D for different data_type classes (an image, pixel-scale, noise-map, etc.)
 
         Parameters
         ----------
-        data : arrays.Array
+        data : abstract_structure.AbstractStructure
             The array of the image data, in units of electrons per second.
-        pixel_scales : float
-            The size of each pixel in arc seconds.
-        psf : PSF
-            An array describing the PSF kernel of the image.
-        noise_map : ndarray
+        noise_map : abstract_structure.AbstractStructure
             An array describing the RMS standard deviation error in each pixel, preferably in units of electrons per
             second.
         """
@@ -135,6 +138,19 @@ class AbstractDataset:
 
         return imaging
 
+    def trimmed_after_convolution_from(self, kernel_shape):
+
+        imaging = copy.copy(self)
+
+        imaging.data = imaging.data.trimmed_after_convolution_from(
+            kernel_shape=kernel_shape
+        )
+        imaging.noise_map = imaging.noise_map.trimmed_after_convolution_from(
+            kernel_shape=kernel_shape
+        )
+
+        return imaging
+
 
 class AbstractSettingsMaskedDataset:
     def __init__(
@@ -157,22 +173,22 @@ class AbstractSettingsMaskedDataset:
         Parameters
         ----------
         grid_class : ag.Grid
-            The type of grid used to create the image from the *Galaxy* and *Plane*. The options are *Grid*,
-            *GridIterate* and *GridInterpolate* (see the *Grids* documentation for a description of these options).
+            The type of grid used to create the image from the `Galaxy` and `Plane`. The options are `Grid`,
+            `GridIterate` and `GridInterpolate` (see the `Grid` documentation for a description of these options).
         grid_inversion_class : ag.Grid
             The type of grid used to create the grid that maps the `Inversion` source pixels to the data's image-pixels.
-            The options are *Grid*, *GridIterate* and *GridInterpolate* (see the *Grids* documentation for a
+            The options are `Grid`, `GridIterate` and `GridInterpolate` (see the `Grid` documentation for a
             description of these options).
         sub_size : int
-            If the grid and / or grid_inversion use a *Grid*, this sets the sub-size used by the *Grid*.
+            If the grid and / or grid_inversion use a `Grid`, this sets the sub-size used by the `Grid`.
         fractional_accuracy : float
-            If the grid and / or grid_inversion use a *GridIterate*, this sets the fractional accuracy it
+            If the grid and / or grid_inversion use a `GridIterate`, this sets the fractional accuracy it
             uses when evaluating functions.
         sub_steps : [int]
-            If the grid and / or grid_inversion use a *GridIterate*, this sets the steps the sub-size is increased by
+            If the grid and / or grid_inversion use a `GridIterate`, this sets the steps the sub-size is increased by
             to meet the fractional accuracy when evaluating functions.
         pixel_scales_interp : float or (float, float)
-            If the grid and / or grid_inversion use a *GridInterpolate*, this sets the resolution of the interpolation
+            If the grid and / or grid_inversion use a `GridInterpolate`, this sets the resolution of the interpolation
             grid.
         signal_to_noise_limit : float
             If input, the dataset's noise-map is rescaled such that no pixel has a signal-to-noise above the
@@ -225,7 +241,7 @@ class AbstractSettingsMaskedDataset:
         """
 
         return (
-            f"{conf.instance.settings_tag.get('dataset', 'grid')}_"
+            f"{conf.instance['notation']['settings_tags']['dataset']['grid']}_"
             f"{self.grid_sub_size_tag}"
             f"{self.grid_fractional_accuracy_tag}"
             f"{self.grid_pixel_scales_interp_tag}"
@@ -238,11 +254,11 @@ class AbstractSettingsMaskedDataset:
         This assumes both grids were used in the analysis.
         """
         return (
-            f"{conf.instance.settings_tag.get('dataset', 'grid')}_"
+            f"{conf.instance['notation']['settings_tags']['dataset']['grid']}_"
             f"{self.grid_sub_size_tag}"
             f"{self.grid_fractional_accuracy_tag}"
             f"{self.grid_pixel_scales_interp_tag}_"
-            f"{conf.instance.settings_tag.get('dataset', 'grid_inversion')}_"
+            f"{conf.instance['notation']['settings_tags']['dataset']['grid_inversion']}_"
             f"{self.grid_inversion_sub_size_tag}"
             f"{self.grid_inversion_fractional_accuracy_tag}"
             f"{self.grid_inversion_pixel_scales_interp_tag}"
@@ -261,7 +277,7 @@ class AbstractSettingsMaskedDataset:
         if not self.grid_class is grids.Grid:
             return ""
         return (
-            f"{conf.instance.settings_tag.get('dataset', 'sub_size')}_"
+            f"{conf.instance['notation']['settings_tags']['dataset']['sub_size']}_"
             f"{str(self.sub_size)}"
         )
 
@@ -278,7 +294,7 @@ class AbstractSettingsMaskedDataset:
         if not self.grid_class is grids.GridIterate:
             return ""
         return (
-            f"{conf.instance.settings_tag.get('dataset', 'fractional_accuracy')}_"
+            f"{conf.instance['notation']['settings_tags']['dataset']['fractional_accuracy']}_"
             f"{str(self.fractional_accuracy)}"
         )
 
@@ -296,9 +312,9 @@ class AbstractSettingsMaskedDataset:
             return ""
         if self.pixel_scales_interp is None:
             return ""
-        return conf.instance.settings_tag.get(
-            "dataset", "pixel_scales_interp"
-        ) + "_{0:.3f}".format(self.pixel_scales_interp)
+        return conf.instance["notation"]["settings_tags"]["dataset"][
+            "pixel_scales_interp"
+        ] + "_{0:.3f}".format(self.pixel_scales_interp)
 
     @property
     def grid_inversion_sub_size_tag(self):
@@ -313,7 +329,7 @@ class AbstractSettingsMaskedDataset:
         if not self.grid_inversion_class is grids.Grid:
             return ""
         return (
-            f"{conf.instance.settings_tag.get('dataset', 'sub_size')}_"
+            f"{conf.instance['notation']['settings_tags']['dataset']['sub_size']}_"
             f"{str(self.sub_size)}"
         )
 
@@ -330,7 +346,7 @@ class AbstractSettingsMaskedDataset:
         if not self.grid_inversion_class is grids.GridIterate:
             return ""
         return (
-            f"{conf.instance.settings_tag.get('dataset', 'fractional_accuracy')}_"
+            f"{conf.instance['notation']['settings_tags']['dataset']['fractional_accuracy']}_"
             f"{str(self.fractional_accuracy)}"
         )
 
@@ -348,9 +364,9 @@ class AbstractSettingsMaskedDataset:
             return ""
         if self.pixel_scales_interp is None:
             return ""
-        return conf.instance.settings_tag.get(
-            "dataset", "pixel_scales_interp"
-        ) + "_{0:.3f}".format(self.pixel_scales_interp)
+        return conf.instance["notation"]["settings_tags"]["dataset"][
+            "pixel_scales_interp"
+        ] + "_{0:.3f}".format(self.pixel_scales_interp)
 
     @property
     def signal_to_noise_limit_tag(self):
@@ -366,7 +382,7 @@ class AbstractSettingsMaskedDataset:
         if self.signal_to_noise_limit is None:
             return ""
         return (
-            f"__{conf.instance.settings_tag.get('dataset', 'signal_to_noise_limit')}_"
+            f"__{conf.instance['notation']['settings_tags']['dataset']['signal_to_noise_limit']}_"
             f"{str(self.signal_to_noise_limit)}"
         )
 
@@ -384,7 +400,7 @@ class AbstractMaskedDataset:
 
         if settings.signal_to_noise_limit is not None:
 
-            dataset = dataset.signal_to_noise_limited_from_signal_to_noise_limit(
+            dataset = dataset.signal_to_noise_limited_from(
                 signal_to_noise_limit=settings.signal_to_noise_limit
             )
 
