@@ -52,7 +52,7 @@ class AbstractInterferometer(abstract_dataset.AbstractDataset):
         interferometer.data = vis.Visibilities(visibilities_1d=visibilities)
         return interferometer
 
-    def signal_to_noise_limited_from_signal_to_noise_limit(self, signal_to_noise_limit):
+    def signal_to_noise_limited_from(self, signal_to_noise_limit):
 
         interferometer = copy.deepcopy(self)
 
@@ -93,22 +93,22 @@ class AbstractSettingsMaskedInterferometer(
           Parameters
           ----------
         grid_class : ag.Grid
-            The type of grid used to create the image from the *Galaxy* and *Plane*. The options are *Grid*,
-            *GridIterate* and *GridInterpolate* (see the *Grids* documentation for a description of these options).
+            The type of grid used to create the image from the `Galaxy` and `Plane`. The options are `Grid`,
+            `GridIterate` and `GridInterpolate` (see the `Grid` documentation for a description of these options).
         grid_inversion_class : ag.Grid
             The type of grid used to create the grid that maps the `Inversion` source pixels to the data's image-pixels.
-            The options are *Grid*, *GridIterate* and *GridInterpolate* (see the *Grids* documentation for a
+            The options are `Grid`, `GridIterate` and `GridInterpolate` (see the `Grid` documentation for a
             description of these options).
         sub_size : int
-            If the grid and / or grid_inversion use a *Grid*, this sets the sub-size used by the *Grid*.
+            If the grid and / or grid_inversion use a `Grid`, this sets the sub-size used by the `Grid`.
         fractional_accuracy : float
-            If the grid and / or grid_inversion use a *GridIterate*, this sets the fractional accuracy it
+            If the grid and / or grid_inversion use a `GridIterate`, this sets the fractional accuracy it
             uses when evaluating functions.
         sub_steps : [int]
-            If the grid and / or grid_inversion use a *GridIterate*, this sets the steps the sub-size is increased by
+            If the grid and / or grid_inversion use a `GridIterate`, this sets the steps the sub-size is increased by
             to meet the fractional accuracy when evaluating functions.
         pixel_scales_interp : float or (float, float)
-            If the grid and / or grid_inversion use a *GridInterpolate*, this sets the resolution of the interpolation
+            If the grid and / or grid_inversion use a `GridInterpolate`, this sets the resolution of the interpolation
             grid.
         signal_to_noise_limit : float
             If input, the dataset's noise-map is rescaled such that no pixel has a signal-to-noise above the
@@ -130,7 +130,7 @@ class AbstractSettingsMaskedInterferometer(
     @property
     def tag_no_inversion(self):
         return (
-            f"{conf.instance.settings_tag.get('interferometer', 'interferometer')}["
+            f"{conf.instance['notation']['settings_tags']['interferometer']['interferometer']}["
             f"{self.grid_tag_no_inversion}"
             f"{self.transformer_tag}"
             f"{self.signal_to_noise_limit_tag}]"
@@ -139,7 +139,7 @@ class AbstractSettingsMaskedInterferometer(
     @property
     def tag_with_inversion(self):
         return (
-            f"{conf.instance.settings_tag.get('interferometer', 'interferometer')}["
+            f"{conf.instance['notation']['settings_tags']['interferometer']['interferometer']}["
             f"{self.grid_tag_with_inversion}"
             f"{self.transformer_tag}"
             f"{self.signal_to_noise_limit_tag}]"
@@ -158,7 +158,7 @@ class AbstractSettingsMaskedInterferometer(
         """
         if self.transformer_class is None:
             return ""
-        return f"__{conf.instance.settings_tag.get('interferometer', self.transformer_class.__name__)}"
+        return f"__{conf.instance['notation']['settings_tags']['interferometer'][self.transformer_class.__name__]}"
 
 
 class AbstractMaskedInterferometer(abstract_dataset.AbstractMaskedDataset):
@@ -225,109 +225,6 @@ class AbstractMaskedInterferometer(abstract_dataset.AbstractMaskedDataset):
         return masked_interferometer
 
 
-class AbstractSimulatorInterferometer:
-    def __init__(
-        self,
-        uv_wavelengths,
-        exposure_time_map,
-        background_sky_map=None,
-        transformer_class=trans.TransformerDFT,
-        noise_sigma=0.1,
-        noise_if_add_noise_false=0.1,
-        noise_seed=-1,
-    ):
-        """A class representing a Imaging observation, using the shape of the image, the pixel scale,
-        psf, exposure time, etc.
-
-        Parameters
-        ----------
-        real_space_shape_2d : (int, int)
-            The shape of the observation. Note that we do not simulator a full Imaging frame (e.g. 2000 x 2000 pixels for \
-            Hubble imaging), but instead just a cut-out around the strong lens.
-        real_space_pixel_scales : float
-            The size of each pixel in arc seconds.
-        psf : PSF
-            An arrays describing the PSF kernel of the image.
-        exposure_time_map : float
-            The exposure time of an observation using this data_type.
-        background_sky_map : float
-            The level of the background sky of an observationg using this data_type.
-        """
-
-        self.uv_wavelengths = uv_wavelengths
-        self.exposure_time_map = exposure_time_map
-        self.background_sky_map = background_sky_map
-        self.transformer_class = transformer_class
-        self.noise_sigma = noise_sigma
-        self.noise_if_add_noise_false = noise_if_add_noise_false
-        self.noise_seed = noise_seed
-
-    def from_image(self, image, name=None):
-        """
-        Create a realistic simulated image by applying effects to a plain simulated image.
-
-        Parameters
-        ----------
-        name
-        real_space_image : ndarray
-            The image before simulating (e.g. the lens and source galaxies before optics blurring and UVPlane read-out).
-        real_space_pixel_scales: float
-            The scale of each pixel in arc seconds
-        exposure_time_map : ndarray
-            An array representing the effective exposure time of each pixel.
-        psf: PSF
-            An array describing the PSF the simulated image is blurred with.
-        background_sky_map : ndarray
-            The value of background sky in every image pixel (electrons per second).
-        add_noise: Bool
-            If True poisson noise_maps is simulated and added to the image, based on the total counts in each image
-            pixel
-        noise_seed: int
-            A seed for random noise_maps generation
-        """
-
-        transformer = self.transformer_class(
-            uv_wavelengths=self.uv_wavelengths, real_space_mask=image.mask
-        )
-
-        if self.background_sky_map is not None:
-            background_sky_map = self.background_sky_map
-        else:
-            background_sky_map = arrays.Array.zeros(
-                shape_2d=image.shape_2d, pixel_scales=image.pixel_scales
-            )
-
-        image = image + background_sky_map
-
-        visibilities = transformer.visibilities_from_image(image=image)
-
-        if self.noise_sigma is not None:
-            visibilities = preprocess.data_with_gaussian_noise_added(
-                data=visibilities, sigma=self.noise_sigma, seed=self.noise_seed
-            )
-            noise_map = vis.Visibilities.full(
-                fill_value=self.noise_sigma, shape_1d=(visibilities.shape[0],)
-            )
-        else:
-            noise_map = vis.Visibilities.full(
-                fill_value=self.noise_if_add_noise_false,
-                shape_1d=(visibilities.shape[0],),
-            )
-
-        if np.isnan(noise_map).any():
-            raise exc.DataException(
-                "The noise-map has NaN values in it. This suggests your exposure time and / or"
-                "background sky levels are too low, creating signal counts at or close to 0.0."
-            )
-
-        return Interferometer(
-            visibilities=visibilities,
-            noise_map=noise_map,
-            uv_wavelengths=transformer.uv_wavelengths,
-            name=name,
-        )
-
-
 class Interferometer(AbstractInterferometer):
     @classmethod
     def from_fits(
@@ -411,6 +308,108 @@ class MaskedInterferometer(AbstractMaskedInterferometer):
     pass
 
 
+class AbstractSimulatorInterferometer:
+    def __init__(
+        self,
+        uv_wavelengths,
+        exposure_time: float,
+        background_sky_level: float = 0.0,
+        transformer_class=trans.TransformerDFT,
+        noise_sigma=0.1,
+        noise_if_add_noise_false=0.1,
+        noise_seed=-1,
+    ):
+        """A class representing a Imaging observation, using the shape of the image, the pixel scale,
+        psf, exposure time, etc.
+
+        Parameters
+        ----------
+        real_space_shape_2d : (int, int)
+            The shape of the observation. Note that we do not simulator a full Imaging frame (e.g. 2000 x 2000 pixels for \
+            Hubble imaging), but instead just a cut-out around the strong lens.
+        real_space_pixel_scales : float
+            The size of each pixel in scaled units.
+        psf : PSF
+            An arrays describing the PSF kernel of the image.
+        exposure_time_map : float
+            The exposure time of an observation using this data_type.
+        background_sky_map : float
+            The level of the background sky of an observationg using this data_type.
+        """
+
+        self.uv_wavelengths = uv_wavelengths
+        self.exposure_time = exposure_time
+        self.background_sky_level = background_sky_level
+        self.transformer_class = transformer_class
+        self.noise_sigma = noise_sigma
+        self.noise_if_add_noise_false = noise_if_add_noise_false
+        self.noise_seed = noise_seed
+
+    def from_image(self, image, name=None):
+        """
+        Returns a realistic simulated image by applying effects to a plain simulated image.
+
+        Parameters
+        ----------
+        name
+        real_space_image : np.ndarray
+            The image before simulating (e.g. the lens and source galaxies before optics blurring and UVPlane read-out).
+        real_space_pixel_scales: float
+            The scale of each pixel in scaled units
+        exposure_time_map : np.ndarray
+            An array representing the effective exposure time of each pixel.
+        psf: PSF
+            An array describing the PSF the simulated image is blurred with.
+        background_sky_map : np.ndarray
+            The value of background sky in every image pixel (electrons per second).
+        add_poisson_noise: Bool
+            If `True` poisson noise_maps is simulated and added to the image, based on the total counts in each image
+            pixel
+        noise_seed: int
+            A seed for random noise_maps generation
+        """
+
+        transformer = self.transformer_class(
+            uv_wavelengths=self.uv_wavelengths, real_space_mask=image.mask
+        )
+
+        background_sky_map = arrays.Array.full(
+            fill_value=self.background_sky_level,
+            shape_2d=image.shape_2d,
+            pixel_scales=image.pixel_scales,
+        )
+
+        image = image + background_sky_map
+
+        visibilities = transformer.visibilities_from_image(image=image)
+
+        if self.noise_sigma is not None:
+            visibilities = preprocess.data_with_gaussian_noise_added(
+                data=visibilities, sigma=self.noise_sigma, seed=self.noise_seed
+            )
+            noise_map = vis.Visibilities.full(
+                fill_value=self.noise_sigma, shape_1d=(visibilities.shape[0],)
+            )
+        else:
+            noise_map = vis.Visibilities.full(
+                fill_value=self.noise_if_add_noise_false,
+                shape_1d=(visibilities.shape[0],),
+            )
+
+        if np.isnan(noise_map).any():
+            raise exc.DatasetException(
+                "The noise-map has NaN values in it. This suggests your exposure time and / or"
+                "background sky levels are too low, creating signal counts at or close to 0.0."
+            )
+
+        return Interferometer(
+            visibilities=visibilities,
+            noise_map=noise_map,
+            uv_wavelengths=transformer.uv_wavelengths,
+            name=name,
+        )
+
+
 class SimulatorInterferometer(AbstractSimulatorInterferometer):
 
     pass
