@@ -6,21 +6,29 @@ from autoarray.util import fit_util
 class FitDataset:
 
     # noinspection PyUnresolvedReferences
-    def __init__(self, masked_dataset, model_data, inversion=None):
+    def __init__(
+        self, masked_dataset, model_data, inversion=None, use_mask_in_fit=True
+    ):
         """Class to fit a masked dataset where the dataset's data structures are any dimension.
 
         Parameters
         -----------
         masked_dataset : MaskedDataset
             The masked dataset (data, mask, noise-map, etc.) that is fitted.
-        model_data : ndarray
+        model_data : np.ndarray
             The model data the masked dataset is fitted with.
+        inversion : Inversion
+            If the fit uses an `Inversion` this is the instance of the object used to perform the fit. This determines
+            if the `log_likelihood` or `log_evidence` is used as the `figure_of_merit`.
+        use_mask_in_fit : bool
+            If `True`, masked data points are omitted from the fit. If `False` they are not (in most use cases the
+            `masked_dataset` will have been processed to remove masked points, for example the `in_1d` representation).
 
         Attributes
         -----------
-        residual_map : ndarray
+        residual_map : np.ndarray
             The residual-map of the fit (data - model_data).
-        chi_squared_map : ndarray
+        chi_squared_map : np.ndarray
             The chi-squared-map of the fit ((data - model_data) / noise_maps ) **2.0
         chi_squared : float
             The overall chi-squared of the model's fit to the dataset, summed over every data point.
@@ -36,6 +44,7 @@ class FitDataset:
         self.masked_dataset = masked_dataset
         self.model_data = model_data
         self.inversion = inversion
+        self.use_mask_in_fit = use_mask_in_fit
 
     @property
     def name(self):
@@ -55,28 +64,43 @@ class FitDataset:
 
     @property
     def residual_map(self):
-        """Compute the residual-map between the masked dataset and model data, where:
+        """
+    Returns the residual-map between the masked dataset and model data, where:
 
         Residuals = (Data - Model_Data).
         """
+        if self.use_mask_in_fit:
+            return fit_util.residual_map_with_mask_from(
+                data=self.data, model_data=self.model_data, mask=self.mask
+            )
         return fit_util.residual_map_from(data=self.data, model_data=self.model_data)
 
     @property
     def normalized_residual_map(self):
-        """Compute the normalized residual-map between the masked dataset and model data, where:
+        """
+    Returns the normalized residual-map between the masked dataset and model data, where:
 
         Normalized_Residual = (Data - Model_Data) / Noise
         """
+        if self.use_mask_in_fit:
+            return fit_util.normalized_residual_map_with_mask_from(
+                residual_map=self.residual_map, noise_map=self.noise_map, mask=self.mask
+            )
         return fit_util.normalized_residual_map_from(
             residual_map=self.residual_map, noise_map=self.noise_map
         )
 
     @property
     def chi_squared_map(self):
-        """Compute the chi-squared-map between the residual-map and noise-map, where:
+        """
+    Returns the chi-squared-map between the residual-map and noise-map, where:
 
         Chi_Squared = ((Residuals) / (Noise)) ** 2.0 = ((Data - Model)**2.0)/(Variances)
         """
+        if self.use_mask_in_fit:
+            return fit_util.chi_squared_map_with_mask_from(
+                residual_map=self.residual_map, noise_map=self.noise_map, mask=self.mask
+            )
         return fit_util.chi_squared_map_from(
             residual_map=self.residual_map, noise_map=self.noise_map
         )
@@ -90,8 +114,13 @@ class FitDataset:
 
     @property
     def chi_squared(self):
-        """Compute the chi-squared terms of the model data's fit to an dataset, by summing the chi-squared-map.
         """
+        Returns the chi-squared terms of the model data's fit to an dataset, by summing the chi-squared-map.
+        """
+        if self.use_mask_in_fit:
+            return fit_util.chi_squared_with_mask_from(
+                chi_squared_map=self.chi_squared_map, mask=self.mask
+            )
         return fit_util.chi_squared_from(chi_squared_map=self.chi_squared_map)
 
     @property
@@ -100,15 +129,21 @@ class FitDataset:
 
     @property
     def noise_normalization(self):
-        """Compute the noise-map normalization term of the noise-map, summing the noise_map value in every pixel as:
+        """
+    Returns the noise-map normalization term of the noise-map, summing the noise_map value in every pixel as:
 
         [Noise_Term] = sum(log(2*pi*[Noise]**2.0))
         """
+        if self.use_mask_in_fit:
+            return fit_util.noise_normalization_with_mask_from(
+                noise_map=self.noise_map, mask=self.mask
+            )
         return fit_util.noise_normalization_from(noise_map=self.noise_map)
 
     @property
     def log_likelihood(self):
-        """Compute the log likelihood of each model data point's fit to the dataset, where:
+        """
+    Returns the log likelihood of each model data point's fit to the dataset, where:
 
         Log Likelihood = -0.5*[Chi_Squared_Term + Noise_Term] (see functions above for these definitions)
         """
@@ -118,7 +153,8 @@ class FitDataset:
 
     @property
     def log_likelihood_with_regularization(self):
-        """Compute the log likelihood of an inversion's fit to the dataset, including a regularization term which \
+        """
+    Returns the log likelihood of an inversion's fit to the dataset, including a regularization term which \
         comes from an inversion:
 
         Log Likelihood = -0.5*[Chi_Squared_Term + Regularization_Term + Noise_Term] (see functions above for these definitions)
@@ -132,7 +168,8 @@ class FitDataset:
 
     @property
     def log_evidence(self):
-        """Compute the log evidence of the inversion's fit to a dataset, where the log evidence includes a number of terms
+        """
+    Returns the log evidence of the inversion's fit to a dataset, where the log evidence includes a number of terms
         which quantify the complexity of an inversion's reconstruction (see the `Inversion` module):
 
         Log Evidence = -0.5*[Chi_Squared_Term + Regularization_Term + Log(Covariance_Regularization_Term) -
@@ -177,7 +214,9 @@ class FitDataset:
 
 
 class FitImaging(FitDataset):
-    def __init__(self, masked_imaging, model_image, inversion=None):
+    def __init__(
+        self, masked_imaging, model_image, inversion=None, use_mask_in_fit=True
+    ):
         """Class to fit a masked imaging dataset.
 
         Parameters
@@ -186,12 +225,18 @@ class FitImaging(FitDataset):
             The masked imaging dataset that is fitted.
         model_image : Array
             The model image the masked imaging is fitted with.
+        inversion : Inversion
+            If the fit uses an `Inversion` this is the instance of the object used to perform the fit. This determines
+            if the `log_likelihood` or `log_evidence` is used as the `figure_of_merit`.
+        use_mask_in_fit : bool
+            If `True`, masked data points are omitted from the fit. If `False` they are not (in most use cases the
+            `masked_dataset` will have been processed to remove masked points, for example the `in_1d` representation).
 
         Attributes
         -----------
-        residual_map : ndarray
+        residual_map : np.ndarray
             The residual-map of the fit (data - model_data).
-        chi_squared_map : ndarray
+        chi_squared_map : np.ndarray
             The chi-squared-map of the fit ((data - model_data) / noise_maps ) **2.0
         chi_squared : float
             The overall chi-squared of the model's fit to the dataset, summed over every data point.
@@ -205,7 +250,10 @@ class FitImaging(FitDataset):
         """
 
         super().__init__(
-            masked_dataset=masked_imaging, model_data=model_image, inversion=inversion
+            masked_dataset=masked_imaging,
+            model_data=model_image,
+            inversion=inversion,
+            use_mask_in_fit=use_mask_in_fit,
         )
 
     @property
@@ -222,7 +270,13 @@ class FitImaging(FitDataset):
 
 
 class FitInterferometer(FitDataset):
-    def __init__(self, masked_interferometer, model_visibilities, inversion=None):
+    def __init__(
+        self,
+        masked_interferometer,
+        model_visibilities,
+        inversion=None,
+        use_mask_in_fit=True,
+    ):
         """Class to fit a masked interferometer dataset.
 
         Parameters
@@ -231,12 +285,18 @@ class FitInterferometer(FitDataset):
             The masked interferometer dataset that is fitted.
         model_visibilities : Visibilities
             The model visibilities the masked imaging is fitted with.
+        inversion : Inversion
+            If the fit uses an `Inversion` this is the instance of the object used to perform the fit. This determines
+            if the `log_likelihood` or `log_evidence` is used as the `figure_of_merit`.
+        use_mask_in_fit : bool
+            If `True`, masked data points are omitted from the fit. If `False` they are not (in most use cases the
+            `masked_dataset` will have been processed to remove masked points, for example the `in_1d` representation).
 
         Attributes
         -----------
-        residual_map : ndarray
+        residual_map : np.ndarray
             The residual-map of the fit (data - model_data).
-        chi_squared_map : ndarray
+        chi_squared_map : np.ndarray
             The chi-squared-map of the fit ((data - model_data) / noise_maps ) **2.0
         chi_squared : float
             The overall chi-squared of the model's fit to the dataset, summed over every data point.
@@ -253,6 +313,7 @@ class FitInterferometer(FitDataset):
             masked_dataset=masked_interferometer,
             model_data=model_visibilities,
             inversion=inversion,
+            use_mask_in_fit=use_mask_in_fit,
         )
 
     @property
