@@ -14,30 +14,37 @@ class AbstractMask(np.ndarray):
     pixel_scales = None
 
     # noinspection PyUnusedLocal
-    def __new__(cls, mask, origin, pixel_scales=None, sub_size=1, *args, **kwargs):
-        """ A 2D mask, representing a uniform rectangular grid of neighboring rectangular pixels.
+    def __new__(
+        cls,
+        mask: np.ndarray,
+        origin: tuple,
+        pixel_scales: tuple,
+        sub_size: int = 1,
+        *args,
+        **kwargs
+    ):
+        """ An abstract class for a mask that represents data structure that can be in 1D, 2D or other shapes.
 
-        A mask s applied to an Array or Grid structure to signify which entries are used in calculations, where a
-        *False* entry signifies that the mask entry is unmasked and therefore is used in calculations.
+        When applied to data it extracts or masks the unmasked image pixels corresponding to mask entries that are
+       `False` or 0).
 
-        The mask defines the geometry of the 2D uniform grid of pixels, for example their pixel scale and coordinate
-        origin. The 2D uniform grid may also be sub-gridded, whereby every pixel is sub-divided into a uniform gridd
-        of sub-pixels which are all used to perform calculations more accurate. See *Grid* for a detailed description
-        of sub-gridding.
+       The mask also defines the geometry of the data structure it is paired with, for example how its pixels convert
+       to physical units via the ``pixel_scales`` and ``origin`` parameters and a sub-grid which is used for
+       perform calculations via super-sampling.
 
         Parameters
         ----------
-        mask: ndarray
-            The array of shape [total_y_pixels, total_x_pixels] containing the bools representing the mask, where
-            *False* signifies an entry is unmasked and used in calculations.
-        pixel_scales: (float, float) or float
-            The (y,x) arc-second to pixel conversion factors of every pixel. If this is input as a float, it is
-            converted to a (float, float) structure.
+        mask : np.ndarray
+            The ``ndarray`` containing the ``bool``'s representing the ``mask``, where `False` signifies an entry is
+            unmasked and used in calculations.
+        pixel_scales : (float, float) or float
+            The scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``, it is
+            converted to a ``(float, float)`` structure.
         origin : (float, float)
-            The (y,x) arc-second origin of the mask's coordinate system.
+            The origin of the ``mask``'s coordinate system in scaled units.
         """
-        # noinspection PyArgumentList
 
+        # noinspection PyArgumentList
         mask = mask.astype("bool")
         obj = mask.view(cls)
         obj.sub_size = sub_size
@@ -75,11 +82,15 @@ class AbstractMask(np.ndarray):
 
     @property
     def pixel_scale(self):
+        """
+        For a mask with dimensions two or above check that are pixel scales are the same, and if so return this
+        single value as a ``float``.
+        """
 
         for pixel_scale in self.pixel_scales:
             if pixel_scale != self.pixel_scales[0]:
                 raise exc.MaskException(
-                    "Cannot return a pixel_scale for a a grid where each dimension has a "
+                    "Cannot return a pixel_scale for a grid where each dimension has a "
                     "different pixel scale (e.g. pixel_scales[0] != pixel_scales[1]"
                 )
 
@@ -102,53 +113,81 @@ class AbstractMask(np.ndarray):
         return regions.Regions(mask=self)
 
     @property
-    def sub_length(self):
-        """The total number of sub-pixels in a give pixel.
+    def sub_length(self) -> int:
+        """
+        The total number of sub-pixels in a give pixel,
 
-        For example, a sub-size of 3x3 means every pixel has 9 sub-pixels."""
+        For example, a sub-size of 3x3 means every pixel has 9 sub-pixels.
+        """
         return int(self.sub_size ** 2.0)
 
     @property
-    def sub_fraction(self):
-        """The fraction of the area of a pixel every sub-pixel contains.
+    def sub_fraction(self) -> float:
+        """
+        The fraction of the area of a pixel every sub-pixel contains.
 
-        For example, a sub-size of 3x3 mean every pixel contains 1/9 the area."""
+        For example, a sub-size of 3x3 mean every pixel contains 1/9 the area.
+        """
         return 1.0 / self.sub_length
 
-    def output_to_fits(self, file_path, overwrite=False):
+    def output_to_fits(self, file_path: str, overwrite: bool = False):
         raise NotImplementedError()
 
     @property
-    def pixels_in_mask(self):
+    def pixels_in_mask(self) -> int:
+        """
+        The total number of unmasked pixels (values are `False`) in the mask.
+        """
         return int(np.size(self) - np.sum(self))
 
     @property
-    def is_all_true(self):
+    def is_all_true(self) -> bool:
+        """
+        Returns `True` if all pixels in a mask are `True`, else returns `False`.
+        """
         return self.pixels_in_mask == 0
 
     @property
-    def is_all_false(self):
+    def is_all_false(self) -> bool:
+        """
+        Returns `False` if all pixels in a mask are `False`, else returns `True`.
+        """
         return self.pixels_in_mask == np.size(self)
 
     @property
-    def sub_pixels_in_mask(self):
+    def sub_pixels_in_mask(self) -> int:
+        """
+        The total number of unmasked sub-pixels (values are `False`) in the mask.
+        """
         return self.sub_size ** 2 * self.pixels_in_mask
 
     @property
-    def shape_1d(self):
+    def shape_1d(self) -> int:
+        """
+        The 1D shape of the mask, which is equivalent to the total number of unmasked pixels in the mask.
+        """
         return self.pixels_in_mask
 
     @property
-    def sub_shape_1d(self):
+    def sub_shape_1d(self) -> int:
+        """
+        The 1D shape of the masks's sub-grid, which is equivalent to the total number of unmasked pixels in the mask.
+        """
         return int(self.pixels_in_mask * self.sub_size ** 2.0)
 
     @property
-    def mask_sub_1(self):
+    def mask_sub_1(self) -> "AbstractMask":
+        """
+        Returns the mask on the same scaled coordinate system but with a sub-grid of ``sub_size`` `.
+        """
         return self.__class__(
             mask=self, sub_size=1, pixel_scales=self.pixel_scales, origin=self.origin
         )
 
-    def mask_new_sub_size_from_mask(self, mask, sub_size=1):
+    def mask_new_sub_size_from_mask(self, mask, sub_size=1) -> "AbstractMask":
+        """
+        Returns the mask on the same scaled coordinate system but with a sub-grid of an input``sub_size`` `.
+        """
         return self.__class__(
             mask=mask,
             sub_size=sub_size,
@@ -156,10 +195,16 @@ class AbstractMask(np.ndarray):
             origin=self.origin,
         )
 
-    def binned_pixel_scales_from_bin_up_factor(self, bin_up_factor):
+    def binned_pixel_scales_from_bin_up_factor(self, bin_up_factor: int) -> tuple:
+        """
+        If the mask is binned up to a coarser resolution, computes the ``pixel_scales`` of the binned up mask
+
+        Parameters
+        ----------
+        bin_up_factor : int
+            The factor by which the mask is binned up to a coarser resolution.
+        """
         if self.pixel_scales is not None:
             return tuple(
                 pixel_scale * bin_up_factor for pixel_scale in self.pixel_scales
             )
-        else:
-            return None
