@@ -1,18 +1,15 @@
-from autoconf import conf
 import matplotlib
-import configparser
 
-try:
-    backend = conf.get_matplotlib_backend()
-except configparser.NoSectionError:
-    backend = "default"
+from autoconf import conf
 
-if not backend in "default":
+backend = conf.get_matplotlib_backend()
+
+if backend not in "default":
     matplotlib.use(backend)
 
 try:
-    hpc_mode = conf.instance.general.get("hpc", "hpc_mode", bool)
-except configparser.NoSectionError:
+    hpc_mode = conf.instance["general"]["hpc"]["hpc_mode"]
+except KeyError:
     hpc_mode = False
 
 if hpc_mode:
@@ -25,7 +22,6 @@ from functools import wraps
 import copy
 
 from autoarray import exc
-from autoarray.structures import grids
 from autoarray.plot import mat_objs
 import inspect
 import os
@@ -243,7 +239,7 @@ class AbstractPlotter:
             If True, the 2D region of the array corresponding to the rectangle encompassing all unmasked values is \
             plotted, thereby zooming into the region of interest.
         border : bool
-            If a mask is supplied, its borders pixels (e.g. the exterior edge) is plotted if this is *True*.
+            If a mask is supplied, its borders pixels (e.g. the exterior edge) is plotted if this is `True`.
         positions : [[]]
             Lists of (y,x) coordinates on the image which are plotted as colored dots, to highlight specific pixels.
         grid : data_type.array.aa.Grid
@@ -255,7 +251,7 @@ class AbstractPlotter:
         unit_conversion_factor : float or None
             The conversion factor between arc-seconds and kiloparsecs, required to plotters the unit_label in kpc.
         figsize : (int, int)
-            The size of the figure in (rows, columns).
+            The size of the figure in (total_y_pixels, total_x_pixels).
         aspect : str
             The aspect ratio of the array, specifically whether it is forced to be square ('equal') or adapts its size to \
             the figure size ('auto').
@@ -311,7 +307,7 @@ class AbstractPlotter:
             plotters.plot_array(
             array=image, origin=(0.0, 0.0), mask=circular_mask,
             border=False, points=[[1.0, 1.0], [2.0, 2.0]], grid=None, as_subplot=False,
-            unit_label='scaled', kpc_per_arcsec=None, figsize=(7,7), aspect='auto',
+            unit_label='scaled', kpc_per_scaled=None, figsize=(7,7), aspect='auto',
             cmap='jet', norm='linear, norm_min=None, norm_max=None, linthresh=None, linscale=None,
             cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
             title='Image', titlesize=16, xsize=16, ysize=16, xyticksize=16,
@@ -439,7 +435,7 @@ class AbstractPlotter:
             If True, the 2D region of the array corresponding to the rectangle encompassing all unmasked values is \
             plotted, thereby zooming into the region of interest.
         border : bool
-            If a mask is supplied, its borders pixels (e.g. the exterior edge) is plotted if this is *True*.
+            If a mask is supplied, its borders pixels (e.g. the exterior edge) is plotted if this is `True`.
         positions : [[]]
             Lists of (y,x) coordinates on the image which are plotted as colored dots, to highlight specific pixels.
         grid : data_type.array.aa.Grid
@@ -451,7 +447,7 @@ class AbstractPlotter:
         unit_conversion_factor : float or None
             The conversion factor between arc-seconds and kiloparsecs, required to plotters the unit_label in kpc.
         figsize : (int, int)
-            The size of the figure in (rows, columns).
+            The size of the figure in (total_y_pixels, total_x_pixels).
         aspect : str
             The aspect ratio of the array, specifically whether it is forced to be square ('equal') or adapts its size to \
             the figure size ('auto').
@@ -507,7 +503,7 @@ class AbstractPlotter:
             plotter.plot_frame(
             array=image, origin=(0.0, 0.0), mask=circular_mask,
             border=False, points=[[1.0, 1.0], [2.0, 2.0]], grid=None, as_subplot=False,
-            unit_label='scaled', kpc_per_arcsec=None, figsize=(7,7), aspect='auto',
+            unit_label='scaled', kpc_per_scaled=None, figsize=(7,7), aspect='auto',
             cmap='jet', norm='linear, norm_min=None, norm_max=None, linthresh=None, linscale=None,
             cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
             title='Image', titlesize=16, xsize=16, ysize=16, xyticksize=16,
@@ -617,7 +613,7 @@ class AbstractPlotter:
         unit_conversion_factor : float
             The conversion factor between arc-seconds and kiloparsecs, required to plotters the unit_label in kpc.
         figsize : (int, int)
-            The size of the figure in (rows, columns).
+            The size of the figure in (total_y_pixels, total_x_pixels).
         pointsize : int
             The size of the points plotted on the grid.
         xyticksize : int
@@ -1096,7 +1092,6 @@ class Plotter(AbstractPlotter):
         serial_prescan_liner=None,
         serial_overscan_liner=None,
     ):
-
         super(Plotter, self).__init__(
             module=module,
             units=units,
@@ -1181,7 +1176,7 @@ class SubPlotter(AbstractPlotter):
         Parameters
         -----------
         figsize : (int, int)
-            The size of the figure in (rows, columns).
+            The size of the figure in (total_y_pixels, total_x_pixels).
         as_subplot : bool
             If the figure is a subplot, the setup_figure function is omitted to ensure that each subplot does not create a \
             new figure and so that it can be output using the *output.output_figure(structure=None)* function.
@@ -1205,7 +1200,7 @@ class SubPlotter(AbstractPlotter):
             plt.subplot(rows, columns, subplot_index, aspect=float(aspect))
 
     def get_subplot_rows_columns(self, number_subplots):
-        """Get the size of a sub plotters in (rows, columns), based on the number of subplots that are going to be plotted.
+        """Get the size of a sub plotters in (total_y_pixels, total_x_pixels), based on the number of subplots that are going to be plotted.
 
         Parameters
         -----------
@@ -1230,7 +1225,7 @@ class SubPlotter(AbstractPlotter):
             return 6, 6
 
     def get_subplot_figsize(self, number_subplots):
-        """Get the size of a sub plotters in (rows, columns), based on the number of subplots that are going to be plotted.
+        """Get the size of a sub plotters in (total_y_pixels, total_x_pixels), based on the number of subplots that are going to be plotted.
 
         Parameters
         -----------
@@ -1304,14 +1299,12 @@ class Include:
 
     @staticmethod
     def load_include(value, name):
-
-        return (
-            conf.instance.visualize_general.get(
-                section_name="include", attribute_name=name, attribute_type=bool
-            )
-            if value is None
-            else value
-        )
+        if value is not None:
+            """
+            Let is be known that Jam did this - I merely made this horror more efficient
+            """
+            return value
+        return conf.instance["visualize"]["general"]["include"][name]
 
     def grid_from_grid(self, grid):
 
@@ -1342,7 +1335,7 @@ class Include:
         fit : datas.fitting.fitting.AbstractLensHyperFit
             The fit to the datas, which includes a lisrt of every model image, residual_map, chi-squareds, etc.
         include_mask : bool
-            If *True*, the masks is plotted on the fit's datas.
+            If `True`, the masks is plotted on the fit's datas.
         """
         if self.mask:
             return fit.mask
@@ -1357,7 +1350,7 @@ class Include:
         fit : datas.fitting.fitting.AbstractLensHyperFit
             The fit to the datas, which includes a lisrt of every model image, residual_map, chi-squareds, etc.
         include_mask : bool
-            If *True*, the masks is plotted on the fit's datas.
+            If `True`, the masks is plotted on the fit's datas.
         """
         if self.mask:
             return fit.settings_masked_dataset.real_space_mask
@@ -1387,7 +1380,6 @@ class Include:
 
 
 def include_key_from_dictionary(dictionary):
-
     include_key = None
 
     for key, value in dictionary.items():
@@ -1398,7 +1390,6 @@ def include_key_from_dictionary(dictionary):
 
 
 def plotter_key_from_dictionary(dictionary):
-
     plotter_key = None
 
     for key, value in dictionary.items():
@@ -1409,7 +1400,6 @@ def plotter_key_from_dictionary(dictionary):
 
 
 def plotter_and_plotter_key_from_func(func):
-
     defaults = inspect.getfullargspec(func).defaults
     plotter = [value for value in defaults if isinstance(value, AbstractPlotter)][0]
 
@@ -1421,15 +1411,15 @@ def plotter_and_plotter_key_from_func(func):
     return plotter, plotter_key
 
 
-def kpc_per_arcsec_of_object_from_dictionary(dictionary):
+def kpc_per_scaled_of_object_from_dictionary(dictionary):
 
-    kpc_per_arcsec = None
+    kpc_per_scaled = None
 
     for key, value in dictionary.items():
-        if hasattr(value, "kpc_per_arcsec"):
-            return value.kpc_per_arcsec
+        if hasattr(value, "kpc_per_scaled"):
+            return value.kpc_per_scaled
 
-    return kpc_per_arcsec
+    return kpc_per_scaled
 
 
 def set_include_and_plotter(func):
@@ -1554,7 +1544,6 @@ def set_labels(func):
 
     @wraps(func)
     def wrapper(*args, **kwargs):
-
         plotter_key = plotter_key_from_dictionary(dictionary=kwargs)
         plotter = kwargs[plotter_key]
 
@@ -1570,9 +1559,9 @@ def set_labels(func):
 
         plotter = plotter.plotter_with_new_output(filename=filename)
 
-        kpc_per_arcsec = kpc_per_arcsec_of_object_from_dictionary(dictionary=kwargs)
+        kpc_per_scaled = kpc_per_scaled_of_object_from_dictionary(dictionary=kwargs)
 
-        plotter = plotter.plotter_with_new_units(conversion_factor=kpc_per_arcsec)
+        plotter = plotter.plotter_with_new_units(conversion_factor=kpc_per_scaled)
 
         kwargs[plotter_key] = plotter
 
@@ -1591,7 +1580,6 @@ def plot_array(
     include=None,
     plotter=None,
 ):
-
     if include is None:
         include = Include()
 
@@ -1611,7 +1599,6 @@ def plot_array(
 
 
 def plot_frame(frame, include=None, plotter=None):
-
     if include is None:
         include = Include()
 
@@ -1638,7 +1625,6 @@ def plot_grid(
     include=None,
     plotter=None,
 ):
-
     if include is None:
         include = Include()
 
@@ -1667,7 +1653,6 @@ def plot_line(
     vertical_line_labels=None,
     plotter=None,
 ):
-
     if plotter is None:
         plotter = Plotter()
 
@@ -1688,7 +1673,6 @@ def plot_mapper_obj(
     include=None,
     plotter=None,
 ):
-
     if include is None:
         include = Include()
 
