@@ -39,7 +39,7 @@ class Kernel(arrays.Array):
 
     @classmethod
     def manual_1d(
-        cls, array, shape_2d, pixel_scales=None, origin=(0.0, 0.0), renormalize=False
+        cls, array, shape_2d, pixel_scales, origin=(0.0, 0.0), renormalize=False
     ):
         """Create a Kernel (see *Kernel.__new__*) by inputting the kernel values in 1D, for example:
 
@@ -57,13 +57,13 @@ class Kernel(arrays.Array):
             lists.
         shape_2d : (float, float)
             The 2D shape of the mask the array is paired with.
-        pixel_scales : (float, float) or float
-            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
-            are converted to the format (float, float).
+        pixel_scales: (float, float) or float
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+            it is converted to a (float, float) structure.
         sub_size : int
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
-            The origin of the array's mask.
+            The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
             If True, the Kernel's array values are renormalized such that they sum to 1.0.
         """
@@ -74,7 +74,7 @@ class Kernel(arrays.Array):
         return cls(array=array, mask=array.mask, renormalize=renormalize)
 
     @classmethod
-    def manual_2d(cls, array, pixel_scales=None, origin=(0.0, 0.0), renormalize=False):
+    def manual_2d(cls, array, pixel_scales, origin=(0.0, 0.0), renormalize=False):
         """Create an Kernel (see *Kernel.__new__*) by inputting the kernel values in 2D, for example:
 
         kernel=np.ndarray([[1.0, 2.0],
@@ -91,13 +91,13 @@ class Kernel(arrays.Array):
         array : np.ndarray or list
             The values of the array input as an ndarray of shape [total_y_pixels*sub_size, total_x_pixel*sub_size] or a
              list of lists.
-        pixel_scales : (float, float) or float
-            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
-            are converted to the format (float, float).
+        pixel_scales: (float, float) or float
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+            it is converted to a (float, float) structure.
         sub_size : int
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
-            The origin of the array's mask.
+            The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
             If True, the Kernel's array values are renormalized such that they sum to 1.0.
         """
@@ -109,12 +109,7 @@ class Kernel(arrays.Array):
 
     @classmethod
     def manual(
-        cls,
-        array,
-        shape_2d=None,
-        pixel_scales=None,
-        origin=(0.0, 0.0),
-        renormalize=False,
+        cls, array, pixel_scales, shape_2d=None, origin=(0.0, 0.0), renormalize=False
     ):
         """Create a Kernel (see *Kernel.__new__*) by inputting the kernel values in 1D or 2D, automatically
         determining whether to use the 'manual_1d' or 'manual_2d' methods.
@@ -127,13 +122,13 @@ class Kernel(arrays.Array):
             lists.
         shape_2d : (float, float)
             The 2D shape of the mask the array is paired with.
-        pixel_scales : (float, float) or float
-            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
-            are converted to the format (float, float).
+        pixel_scales: (float, float) or float
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+            it is converted to a (float, float) structure.
         sub_size : int
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
-            The origin of the array's mask.
+            The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
             If True, the Kernel's array values are renormalized such that they sum to 1.0.
         """
@@ -157,7 +152,7 @@ class Kernel(arrays.Array):
         cls,
         fill_value,
         shape_2d,
-        pixel_scales=None,
+        pixel_scales,
         sub_size=1,
         origin=(0.0, 0.0),
         renormalize=False,
@@ -174,13 +169,13 @@ class Kernel(arrays.Array):
             The value all array elements are filled with.
         shape_2d : (float, float)
             The 2D shape of the mask the array is paired with.
-        pixel_scales : (float, float) or float
-            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
-            are converted to the format (float, float).
+        pixel_scales: (float, float) or float
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+            it is converted to a (float, float) structure.
         sub_size : int
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
-            The origin of the array's mask.
+            The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
             If True, the Kernel's array values are renormalized such that they sum to 1.0.
         """
@@ -195,7 +190,7 @@ class Kernel(arrays.Array):
         )
 
     @classmethod
-    def ones(cls, shape_2d, pixel_scales=None, origin=(0.0, 0.0), renormalize=False):
+    def ones(cls, shape_2d, pixel_scales, origin=(0.0, 0.0), renormalize=False):
         """Create an Kernel (see *Kernel.__new__*) where all values are filled with ones, analogous to the method numpy
         ndarray.ones.
 
@@ -206,13 +201,13 @@ class Kernel(arrays.Array):
         ----------
         shape_2d : (float, float)
             The 2D shape of the mask the array is paired with.
-        pixel_scales : (float, float) or float
-            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
-            are converted to the format (float, float).
+        pixel_scales: (float, float) or float
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+            it is converted to a (float, float) structure.
         sub_size : int
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
-            The origin of the array's mask.
+            The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
             If True, the Kernel's array values are renormalized such that they sum to 1.0.
         """
@@ -225,7 +220,7 @@ class Kernel(arrays.Array):
         )
 
     @classmethod
-    def zeros(cls, shape_2d, pixel_scales=None, origin=(0.0, 0.0), renormalize=False):
+    def zeros(cls, shape_2d, pixel_scales, origin=(0.0, 0.0), renormalize=False):
         """Create an Kernel (see *Kernel.__new__*) where all values are filled with zeros, analogous to the method numpy
         ndarray.ones.
 
@@ -236,13 +231,13 @@ class Kernel(arrays.Array):
         ----------
         shape_2d : (float, float)
             The 2D shape of the mask the array is paired with.
-        pixel_scales : (float, float) or float
-            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
-            are converted to the format (float, float).
+        pixel_scales: (float, float) or float
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+            it is converted to a (float, float) structure.
         sub_size : int
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
-            The origin of the array's mask.
+            The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
             If True, the Kernel's array values are renormalized such that they sum to 1.0.
         """
@@ -255,15 +250,15 @@ class Kernel(arrays.Array):
         )
 
     @classmethod
-    def no_blur(cls, pixel_scales=None):
+    def no_blur(cls, pixel_scales):
         """Setup the Kernel as a kernel which does not convolve any signal, which is simply an array of shape (1, 1)
         with value 1.
 
         Parameters
         ----------
-        pixel_scales : (float, float) or float
-            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
-            are converted to the format (float, float).
+        pixel_scales: (float, float) or float
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+            it is converted to a (float, float) structure.
         """
 
         array = np.array([[1.0]])
@@ -290,9 +285,9 @@ class Kernel(arrays.Array):
         ----------
         shape_2d : (float, float)
             The 2D shape of the mask the array is paired with.
-        pixel_scales : (float, float) or float
-            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
-            are converted to the format (float, float).
+        pixel_scales: (float, float) or float
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+            it is converted to a (float, float) structure.
         sigma : float
             The value of sigma in the equation, describing the size and full-width half maximum of the Gaussian.
         centre : (float, float)
@@ -370,7 +365,7 @@ class Kernel(arrays.Array):
 
     @classmethod
     def from_fits(
-        cls, file_path, hdu, pixel_scales=None, origin=(0.0, 0.0), renormalize=False
+        cls, file_path, hdu, pixel_scales, origin=(0.0, 0.0), renormalize=False
     ):
         """
         Loads the Kernel from a .fits file.
@@ -378,15 +373,15 @@ class Kernel(arrays.Array):
         Parameters
         ----------
         file_path : str
-            The path the file is output to, including the filename and the '.fits' extension,
+            The path the file is output to, including the filename and the ``.fits`` extension,
             e.g. '/path/to/filename.fits'
         hdu : int
             The Header-Data Unit of the .fits file the array data is loaded from.
-        pixel_scales : (float, float) or float
-            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
-            are converted to the format (float, float).
+        pixel_scales: (float, float) or float
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+            it is converted to a (float, float) structure.
         origin : (float, float)
-            The origin of the array's mask.
+            The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
             If True, the Kernel's array values are renormalized such that they sum to 1.0.
         """
@@ -494,12 +489,12 @@ class Kernel(arrays.Array):
 
         Parameters
         ----------
-        image : ndarray
+        image : np.ndarray
             An array representing the image the Kernel is convolved with.
 
         Returns
         -------
-        convolved_image : ndarray
+        convolved_image : np.ndarray
             An array representing the image after convolution.
 
         Raises
@@ -529,12 +524,12 @@ class Kernel(arrays.Array):
 
         Parameters
         ----------
-        image : ndarray
+        image : np.ndarray
             An array representing the image the Kernel is convolved with.
 
         Returns
         -------
-        convolved_image : ndarray
+        convolved_image : np.ndarray
             An array representing the image after convolution.
 
         Raises
