@@ -1,20 +1,28 @@
+import matplotlib
+
+from autofit import conf
+
+backend = conf.get_matplotlib_backend()
+if "default" not in backend:
+    matplotlib.use(backend)
+
 import numpy as np
 
+from autoarray.fit.fit import FitDataset
 
-def get_real_space_mask_from(mask, fit):
+
+def get_real_space_mask_from(mask: np.ndarray, fit: FitDataset) -> np.ndarray:
     """Get the masks of the fit if the masks should be plotted on the fit.
 
     Parameters
     -----------
-    fit : datas.fitting.fitting.AbstractLensHyperFit
+    fit : FitDataset
         The fit to the datas, which includes a lisrt of every model image, residual_map, chi-squareds, etc.
     mask : bool
-        If *True*, the masks is plotted on the fit's datas.
+        If `True`, the masks is plotted on the fit's datas.
     """
     if mask:
-        return fit.settings_masked_dataset.mask
-    else:
-        return None
+        return fit.masked_dataset.settings.mask
 
 
 def radii_bin_size_from_minimum_and_maximum_radii_and_radii_points(
@@ -34,7 +42,6 @@ def quantity_radii_from_minimum_and_maximum_radii_and_radii_points(
 def quantity_and_annuli_radii_from_minimum_and_maximum_radii_and_radii_points(
     minimum_radius, maximum_radius, radii_points
 ):
-
     radii_bin_size = radii_bin_size_from_minimum_and_maximum_radii_and_radii_points(
         minimum_radius=minimum_radius,
         maximum_radius=maximum_radius,
