@@ -4,7 +4,34 @@ import numpy as np
 
 
 @decorator_util.jit()
-def preload_real_transforms(grid_radians, uv_wavelengths):
+def preload_real_transforms(
+    grid_radians: np.ndarray, uv_wavelengths: np.ndarray
+) -> np.ndarray:
+    """
+    Sets up the real preloaded values used by the direct fourier transform (`TransformerDFT`) to speed up
+    the Fourier transform calculations.
+
+    The preloaded values are the cosine terms of every (y,x) radian coordinate on the real-space grid multiplied by
+    everu `uv_wavelength` value.
+
+    For large numbers of visibilities (> 100000) this array requires large amounts of memory ( > 1 GB) and it is
+    recommended this preloading is not used.
+
+    Parameters
+    ----------
+    grid_radians : np.ndarray
+        The grid in radians corresponding to real-space mask within which the image that is Fourier transformed is
+        computed.
+    uv_wavelengths : np.ndarray
+        The wavelengths of the coordinates in the uv-plane for the interferometer dataset that is to be Fourier
+        transformed.
+
+    Returns
+    -------
+    np.ndarray
+        The preloaded values of the cosine terms in the calculation of real entries of the direct Fourier transform.
+
+    """
 
     preloaded_real_transforms = np.zeros(
         shape=(grid_radians.shape[0], uv_wavelengths.shape[0])
@@ -46,7 +73,7 @@ def preload_imag_transforms(grid_radians, uv_wavelengths):
 
 
 @decorator_util.jit()
-def real_visibilities_from_image_via_preload_jit(image_1d, preloaded_reals):
+def real_visibilities_via_preload_jit_from(image_1d, preloaded_reals):
 
     real_visibilities = np.zeros(shape=(preloaded_reals.shape[1]))
 
@@ -79,7 +106,7 @@ def real_visibilities_jit(image_1d, grid_radians, uv_wavelengths):
 
 
 @decorator_util.jit()
-def imag_visibilities_from_image_via_preload_jit(image_1d, preloaded_imags):
+def imag_visibilities_from_via_preload_jit_from(image_1d, preloaded_imags):
 
     imag_visibilities = np.zeros(shape=(preloaded_imags.shape[1]))
 
@@ -112,7 +139,9 @@ def imag_visibilities_jit(image_1d, grid_radians, uv_wavelengths):
 
 
 @decorator_util.jit()
-def real_transformed_mapping_matrix_via_preload_jit(mapping_matrix, preloaded_reals):
+def real_transformed_mapping_matrix_via_preload_jit_from(
+    mapping_matrix, preloaded_reals
+):
 
     transfomed_mapping_matrix = np.zeros(
         (preloaded_reals.shape[1], mapping_matrix.shape[1])
@@ -166,7 +195,9 @@ def real_transformed_mapping_matrix_jit(mapping_matrix, grid_radians, uv_wavelen
 
 
 @decorator_util.jit()
-def imag_transformed_mapping_matrix_via_preload_jit(mapping_matrix, preloaded_imags):
+def imag_transformed_mapping_matrix_via_preload_jit_from(
+    mapping_matrix, preloaded_imags
+):
 
     transfomed_mapping_matrix = np.zeros(
         (preloaded_imags.shape[1], mapping_matrix.shape[1])
