@@ -11,19 +11,19 @@ test_data_dir = "{}/files/imaging/".format(os.path.dirname(os.path.realpath(__fi
 
 def test__array_with_new_shape():
 
-    arr = aa.Array.ones(shape_2d=(3, 3))
+    arr = aa.Array.ones(shape_2d=(3, 3), pixel_scales=1.0)
 
     arr = aa.preprocess.array_with_new_shape(array=arr, new_shape=(5, 5))
 
     assert arr.shape_2d == (5, 5)
 
-    arr = aa.Array.ones(shape_2d=(3, 3))
+    arr = aa.Array.ones(shape_2d=(3, 3), pixel_scales=1.0)
 
     arr = aa.preprocess.array_with_new_shape(array=arr, new_shape=(2, 2))
 
     assert arr.shape_2d == (2, 2)
 
-    arr = aa.Array.ones(shape_2d=(10, 6))
+    arr = aa.Array.ones(shape_2d=(10, 6), pixel_scales=1.0)
 
     arr = aa.preprocess.array_with_new_shape(array=arr, new_shape=(20, 14))
 
@@ -32,8 +32,8 @@ def test__array_with_new_shape():
 
 def test__array_from_electrons_per_second_to_counts():
 
-    arr_eps = aa.Array.ones(shape_2d=(3, 3))
-    exposure_time_map = aa.Array.full(fill_value=2.0, shape_2d=(3, 3))
+    arr_eps = aa.Array.ones(shape_2d=(3, 3), pixel_scales=1.0)
+    exposure_time_map = aa.Array.full(fill_value=2.0, shape_2d=(3, 3), pixel_scales=1.0)
 
     arr_counts = aa.preprocess.array_eps_to_counts(
         array_eps=arr_eps, exposure_time_map=exposure_time_map
@@ -44,8 +44,8 @@ def test__array_from_electrons_per_second_to_counts():
 
 def test__array_from_counts_to_electrons_per_second():
 
-    arr_counts = aa.Array.ones(shape_2d=(3, 3))
-    exposure_time_map = aa.Array.full(fill_value=2.0, shape_2d=(3, 3))
+    arr_counts = aa.Array.ones(shape_2d=(3, 3), pixel_scales=1.0)
+    exposure_time_map = aa.Array.full(fill_value=2.0, shape_2d=(3, 3), pixel_scales=1.0)
 
     arr_eps = aa.preprocess.array_counts_to_eps(
         array_counts=arr_counts, exposure_time_map=exposure_time_map
@@ -56,8 +56,8 @@ def test__array_from_counts_to_electrons_per_second():
 
 def test__array_from_electrons_per_second_to_adus():
 
-    arr_eps = aa.Array.ones(shape_2d=(3, 3))
-    exposure_time_map = aa.Array.full(fill_value=2.0, shape_2d=(3, 3))
+    arr_eps = aa.Array.ones(shape_2d=(3, 3), pixel_scales=1.0)
+    exposure_time_map = aa.Array.full(fill_value=2.0, shape_2d=(3, 3), pixel_scales=1.0)
 
     arr_adus = aa.preprocess.array_eps_to_adus(
         array_eps=arr_eps, exposure_time_map=exposure_time_map, gain=2.0
@@ -74,8 +74,8 @@ def test__array_from_electrons_per_second_to_adus():
 
 def test__array_from_adus_to_electrons_per_second():
 
-    arr_adus = aa.Array.ones(shape_2d=(3, 3))
-    exposure_time_map = aa.Array.full(fill_value=2.0, shape_2d=(3, 3))
+    arr_adus = aa.Array.ones(shape_2d=(3, 3), pixel_scales=1.0)
+    exposure_time_map = aa.Array.full(fill_value=2.0, shape_2d=(3, 3), pixel_scales=1.0)
 
     arr_eps = aa.preprocess.array_adus_to_eps(
         array_adus=arr_adus, exposure_time_map=exposure_time_map, gain=2.0
@@ -92,32 +92,36 @@ def test__array_from_adus_to_electrons_per_second():
 
 def test__noise_map_from_image_exposure_time_map():
 
-    image = aa.Array.ones(shape_2d=(3, 3))
-    exposure_time_map = aa.Array.ones(shape_2d=(3, 3))
+    image = aa.Array.ones(shape_2d=(3, 3), pixel_scales=1.0)
+    exposure_time_map = aa.Array.ones(shape_2d=(3, 3), pixel_scales=1.0)
     poisson_noise_map = aa.preprocess.noise_map_from_data_eps_and_exposure_time_map(
         data_eps=image, exposure_time_map=exposure_time_map
     )
 
     assert (poisson_noise_map.in_2d == np.ones((3, 3))).all()
 
-    image = aa.Array.full(fill_value=4.0, shape_2d=(4, 2))
-    exposure_time_map = aa.Array.ones(shape_2d=(4, 2))
+    image = aa.Array.full(fill_value=4.0, shape_2d=(4, 2), pixel_scales=1.0)
+    exposure_time_map = aa.Array.ones(shape_2d=(4, 2), pixel_scales=1.0)
     poisson_noise_map = aa.preprocess.noise_map_from_data_eps_and_exposure_time_map(
         data_eps=image, exposure_time_map=exposure_time_map
     )
 
     assert (poisson_noise_map.in_2d == 2.0 * np.ones((4, 2))).all()
 
-    image = aa.Array.ones(shape_2d=(1, 5))
-    exposure_time_map = aa.Array.full(fill_value=4.0, shape_2d=(1, 5))
+    image = aa.Array.ones(shape_2d=(1, 5), pixel_scales=1.0)
+    exposure_time_map = aa.Array.full(fill_value=4.0, shape_2d=(1, 5), pixel_scales=1.0)
     poisson_noise_map = aa.preprocess.noise_map_from_data_eps_and_exposure_time_map(
         data_eps=image, exposure_time_map=exposure_time_map
     )
 
     assert (poisson_noise_map.in_2d == 0.5 * np.ones((1, 5))).all()
 
-    image = aa.Array.manual_2d(array=np.array([[5.0, 3.0], [10.0, 20.0]]))
-    exposure_time_map = aa.Array.manual_2d(np.array([[1.0, 2.0], [3.0, 4.0]]))
+    image = aa.Array.manual_2d(
+        array=np.array([[5.0, 3.0], [10.0, 20.0]]), pixel_scales=1.0
+    )
+    exposure_time_map = aa.Array.manual_2d(
+        np.array([[1.0, 2.0], [3.0, 4.0]]), pixel_scales=1.0
+    )
     poisson_noise_map = aa.preprocess.noise_map_from_data_eps_and_exposure_time_map(
         data_eps=image, exposure_time_map=exposure_time_map
     )
@@ -135,9 +139,11 @@ def test__noise_map_from_image_exposure_time_map():
 
 def test__noise_map_from_image_exposure_time_map_and_background_noise_map():
 
-    image = aa.Array.ones(shape_2d=(3, 3))
-    exposure_time_map = aa.Array.ones(shape_2d=(3, 3))
-    background_noise_map = aa.Array.full(fill_value=3.0 ** 0.5, shape_2d=(3, 3))
+    image = aa.Array.ones(shape_2d=(3, 3), pixel_scales=1.0)
+    exposure_time_map = aa.Array.ones(shape_2d=(3, 3), pixel_scales=1.0)
+    background_noise_map = aa.Array.full(
+        fill_value=3.0 ** 0.5, shape_2d=(3, 3), pixel_scales=1.0
+    )
 
     noise_map = aa.preprocess.noise_map_from_data_eps_exposure_time_map_and_background_noise_map(
         data_eps=image,
@@ -147,9 +153,11 @@ def test__noise_map_from_image_exposure_time_map_and_background_noise_map():
 
     assert noise_map.in_2d == pytest.approx(2.0 * np.ones((3, 3)), 1e-2)
 
-    image = aa.Array.ones(shape_2d=(2, 3))
-    exposure_time_map = aa.Array.ones(shape_2d=(2, 3))
-    background_noise_map = aa.Array.full(fill_value=5.0, shape_2d=(2, 3))
+    image = aa.Array.ones(shape_2d=(2, 3), pixel_scales=1.0)
+    exposure_time_map = aa.Array.ones(shape_2d=(2, 3), pixel_scales=1.0)
+    background_noise_map = aa.Array.full(
+        fill_value=5.0, shape_2d=(2, 3), pixel_scales=1.0
+    )
 
     noise_map = aa.preprocess.noise_map_from_data_eps_exposure_time_map_and_background_noise_map(
         data_eps=image,
@@ -167,9 +175,11 @@ def test__noise_map_from_image_exposure_time_map_and_background_noise_map():
         1e-2,
     )
 
-    image = aa.Array.ones(shape_2d=(2, 3))
-    exposure_time_map = aa.Array.full(fill_value=2.0, shape_2d=(2, 3))
-    background_noise_map = aa.Array.full(fill_value=5.0, shape_2d=(2, 3))
+    image = aa.Array.ones(shape_2d=(2, 3), pixel_scales=1.0)
+    exposure_time_map = aa.Array.full(fill_value=2.0, shape_2d=(2, 3), pixel_scales=1.0)
+    background_noise_map = aa.Array.full(
+        fill_value=5.0, shape_2d=(2, 3), pixel_scales=1.0
+    )
 
     noise_map = aa.preprocess.noise_map_from_data_eps_exposure_time_map_and_background_noise_map(
         data_eps=image,
@@ -195,9 +205,13 @@ def test__noise_map_from_image_exposure_time_map_and_background_noise_map():
         1e-2,
     )
 
-    image = aa.Array.manual_2d(array=[[1.0, 2.0], [3.0, 4.0], [5.0, 6.0]])
-    exposure_time_map = aa.Array.ones(shape_2d=(3, 2))
-    background_noise_map = aa.Array.full(fill_value=12.0, shape_2d=(3, 2))
+    image = aa.Array.manual_2d(
+        array=[[1.0, 2.0], [3.0, 4.0], [5.0, 6.0]], pixel_scales=1.0
+    )
+    exposure_time_map = aa.Array.ones(shape_2d=(3, 2), pixel_scales=1.0)
+    background_noise_map = aa.Array.full(
+        fill_value=12.0, shape_2d=(3, 2), pixel_scales=1.0
+    )
 
     noise_map = aa.preprocess.noise_map_from_data_eps_exposure_time_map_and_background_noise_map(
         data_eps=image,
@@ -216,9 +230,13 @@ def test__noise_map_from_image_exposure_time_map_and_background_noise_map():
         1e-2,
     )
 
-    image = aa.Array.manual_2d(array=[[5.0, 3.0], [10.0, 20.0]])
-    exposure_time_map = aa.Array.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]])
-    background_noise_map = aa.Array.full(fill_value=9.0, shape_2d=((2, 2)))
+    image = aa.Array.manual_2d(array=[[5.0, 3.0], [10.0, 20.0]], pixel_scales=1.0)
+    exposure_time_map = aa.Array.manual_2d(
+        array=[[1.0, 2.0], [3.0, 4.0]], pixel_scales=1.0
+    )
+    background_noise_map = aa.Array.full(
+        fill_value=9.0, shape_2d=((2, 2)), pixel_scales=1.0
+    )
 
     noise_map = aa.preprocess.noise_map_from_data_eps_exposure_time_map_and_background_noise_map(
         data_eps=image,
@@ -236,9 +254,13 @@ def test__noise_map_from_image_exposure_time_map_and_background_noise_map():
         1e-2,
     )
 
-    image = aa.Array.manual_2d(array=[[5.0, 3.0], [10.0, 20.0]])
-    exposure_time_map = aa.Array.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]])
-    background_noise_map = aa.Array.manual_2d(array=[[5.0, 6.0], [7.0, 8.0]])
+    image = aa.Array.manual_2d(array=[[5.0, 3.0], [10.0, 20.0]], pixel_scales=1.0)
+    exposure_time_map = aa.Array.manual_2d(
+        array=[[1.0, 2.0], [3.0, 4.0]], pixel_scales=1.0
+    )
+    background_noise_map = aa.Array.manual_2d(
+        array=[[5.0, 6.0], [7.0, 8.0]], pixel_scales=1.0
+    )
 
     noise_map = aa.preprocess.noise_map_from_data_eps_exposure_time_map_and_background_noise_map(
         data_eps=image,
@@ -259,13 +281,17 @@ def test__noise_map_from_image_exposure_time_map_and_background_noise_map():
 
 def test__noise_map_from_weight_map():
 
-    weight_map = aa.Array.manual_2d([[1.0, 4.0, 16.0], [1.0, 4.0, 16.0]])
+    weight_map = aa.Array.manual_2d(
+        [[1.0, 4.0, 16.0], [1.0, 4.0, 16.0]], pixel_scales=1.0
+    )
 
     noise_map = aa.preprocess.noise_map_from_weight_map(weight_map=weight_map.in_2d)
 
     assert (noise_map.in_2d == np.array([[1.0, 0.5, 0.25], [1.0, 0.5, 0.25]])).all()
 
-    weight_map = aa.Array.manual_2d([[1.0, 4.0, 0.0], [1.0, 4.0, 16.0]])
+    weight_map = aa.Array.manual_2d(
+        [[1.0, 4.0, 0.0], [1.0, 4.0, 16.0]], pixel_scales=1.0
+    )
 
     noise_map = aa.preprocess.noise_map_from_weight_map(weight_map=weight_map)
 
@@ -274,7 +300,9 @@ def test__noise_map_from_weight_map():
 
 def test__noise_map_from_inverse_noise_map():
 
-    inverse_noise_map = aa.Array.manual_2d([[1.0, 4.0, 16.0], [1.0, 4.0, 16.0]])
+    inverse_noise_map = aa.Array.manual_2d(
+        [[1.0, 4.0, 16.0], [1.0, 4.0, 16.0]], pixel_scales=1.0
+    )
 
     noise_map = aa.preprocess.noise_map_from_inverse_noise_map(
         inverse_noise_map=inverse_noise_map
@@ -289,7 +317,7 @@ def test__noise_map_with_offset_values_added():
 
     np.random.seed(1)
 
-    noise_map = aa.Array.full(fill_value=3.0, shape_2d=(3, 3))
+    noise_map = aa.Array.full(fill_value=3.0, shape_2d=(3, 3), pixel_scales=1.0)
 
     noise_map = aa.preprocess.array_with_random_uniform_values_added(
         array=noise_map, upper_limit=0.001
@@ -309,7 +337,7 @@ def test__noise_map_with_offset_values_added():
 
 def test__background_noise_map_from_edges_of_image():
 
-    image = aa.Array.manual_2d(np.ones((3, 3)))
+    image = aa.Array.manual_2d(array=np.ones((3, 3)), pixel_scales=1.0)
 
     background_noise_map = aa.preprocess.background_noise_map_from_edges_of_image(
         image=image, no_edges=1
@@ -320,7 +348,8 @@ def test__background_noise_map_from_edges_of_image():
     ).all()
 
     image = aa.Array.manual_2d(
-        [[1, 1, 1, 1], [1, 100, 100, 1], [1, 100, 100, 1], [1, 1, 1, 1]]
+        array=[[1, 1, 1, 1], [1, 100, 100, 1], [1, 100, 100, 1], [1, 1, 1, 1]],
+        pixel_scales=1.0,
     )
 
     background_noise_map = aa.preprocess.background_noise_map_from_edges_of_image(
@@ -338,7 +367,8 @@ def test__background_noise_map_from_edges_of_image():
             [1, 1, 100, 1, 1],
             [1, 1, 1, 1, 1],
             [1, 1, 1, 1, 1],
-        ]
+        ],
+        pixel_scales=1.0,
     )
 
     background_noise_map = aa.preprocess.background_noise_map_from_edges_of_image(
@@ -357,7 +387,8 @@ def test__background_noise_map_from_edges_of_image():
             [14, 15, 100, 16, 17],
             [18, 19, 20, 21, 22],
             [23, 24, 25, 26, 27],
-        ]
+        ],
+        pixel_scales=1.0,
     )
 
     background_noise_map = aa.preprocess.background_noise_map_from_edges_of_image(
@@ -378,7 +409,8 @@ def test__background_noise_map_from_edges_of_image():
             [27, 28, 29, 30, 31, 32, 33],
             [34, 35, 36, 37, 38, 39, 40],
             [41, 42, 43, 44, 45, 46, 47],
-        ]
+        ],
+        pixel_scales=1.0,
     )
 
     background_noise_map = aa.preprocess.background_noise_map_from_edges_of_image(
@@ -394,7 +426,9 @@ def test__background_noise_map_from_edges_of_image():
 def test__exposure_time_map_from_exposure_time_and_inverse_noise_map():
 
     exposure_time = 6.0
-    background_noise_map = aa.Array.full(fill_value=0.25, shape_2d=(3, 3))
+    background_noise_map = aa.Array.full(
+        fill_value=0.25, shape_2d=(3, 3), pixel_scales=1.0
+    )
     background_noise_map[0] = 0.5
 
     exposure_time_map = aa.preprocess.exposure_time_map_from_exposure_time_and_background_noise_map(
@@ -409,8 +443,8 @@ def test__exposure_time_map_from_exposure_time_and_inverse_noise_map():
 
 def test__poisson_noise_from_data():
 
-    data = aa.Array.zeros(shape_2d=(2, 2))
-    exposure_time_map = aa.Array.ones(shape_2d=(2, 2))
+    data = aa.Array.zeros(shape_2d=(2, 2), pixel_scales=1.0)
+    exposure_time_map = aa.Array.ones(shape_2d=(2, 2), pixel_scales=1.0)
 
     poisson_noise = aa.preprocess.poisson_noise_from_data_eps(
         data_eps=data, exposure_time_map=exposure_time_map, seed=1
@@ -418,8 +452,8 @@ def test__poisson_noise_from_data():
 
     assert (poisson_noise.in_2d == np.zeros((2, 2))).all()
 
-    data = aa.Array.manual_2d([[10.0, 0.0], [0.0, 10.0]])
-    exposure_time_map = aa.Array.ones(shape_2d=(2, 2))
+    data = aa.Array.manual_2d(array=[[10.0, 0.0], [0.0, 10.0]], pixel_scales=1.0)
+    exposure_time_map = aa.Array.ones(shape_2d=(2, 2), pixel_scales=1.0)
 
     poisson_noise = aa.preprocess.poisson_noise_from_data_eps(
         data_eps=data, exposure_time_map=exposure_time_map, seed=1
@@ -429,8 +463,8 @@ def test__poisson_noise_from_data():
         poisson_noise.in_2d == np.array([[(10.0 - 9.0), 0], [0, (10.0 - 6.0)]])
     ).all()
 
-    data = aa.Array.full(fill_value=10.0, shape_2d=(2, 2))
-    exposure_time_map = aa.Array.ones(shape_2d=(2, 2))
+    data = aa.Array.full(fill_value=10.0, shape_2d=(2, 2), pixel_scales=1.0)
+    exposure_time_map = aa.Array.ones(shape_2d=(2, 2), pixel_scales=1.0)
 
     poisson_noise = aa.preprocess.poisson_noise_from_data_eps(
         data_eps=data, exposure_time_map=exposure_time_map, seed=1
@@ -439,8 +473,10 @@ def test__poisson_noise_from_data():
     # Use known noise_map_1d map for given seed.
     assert (poisson_noise.in_2d == np.array([[1, 4], [3, 1]])).all()
 
-    data = aa.Array.manual_2d([[10000000.0, 0.0], [0.0, 10000000.0]])
-    exposure_time_map = aa.Array.ones(shape_2d=(2, 2))
+    data = aa.Array.manual_2d(
+        array=[[10000000.0, 0.0], [0.0, 10000000.0]], pixel_scales=1.0
+    )
+    exposure_time_map = aa.Array.ones(shape_2d=(2, 2), pixel_scales=1.0)
 
     poisson_noise = aa.preprocess.poisson_noise_from_data_eps(
         data_eps=data, exposure_time_map=exposure_time_map, seed=1
@@ -451,35 +487,37 @@ def test__poisson_noise_from_data():
 
 def test__data_with_poisson_noised_added():
 
-    data = aa.Array.zeros(shape_2d=(2, 2))
-    exposure_time_map = aa.Array.ones(shape_2d=(2, 2))
+    data = aa.Array.zeros(shape_2d=(2, 2), pixel_scales=1.0)
+    exposure_time_map = aa.Array.ones(shape_2d=(2, 2), pixel_scales=1.0)
     data_with_poisson_noise = aa.preprocess.data_eps_with_poisson_noise_added(
         data_eps=data, exposure_time_map=exposure_time_map, seed=1
     )
 
     assert (data_with_poisson_noise.in_2d == np.zeros((2, 2))).all()
 
-    data = aa.Array.manual_2d([[10.0, 0.0], [0.0, 10.0]])
+    data = aa.Array.manual_2d(array=[[10.0, 0.0], [0.0, 10.0]], pixel_scales=1.0)
 
-    exposure_time_map = aa.Array.ones(shape_2d=(2, 2))
+    exposure_time_map = aa.Array.ones(shape_2d=(2, 2), pixel_scales=1.0)
     data_with_poisson_noise = aa.preprocess.data_eps_with_poisson_noise_added(
         data_eps=data, exposure_time_map=exposure_time_map, seed=1
     )
 
     assert (data_with_poisson_noise.in_2d == np.array([[11, 0], [0, 14]])).all()
 
-    data = aa.Array.full(fill_value=10.0, shape_2d=(2, 2))
+    data = aa.Array.full(fill_value=10.0, shape_2d=(2, 2), pixel_scales=1.0)
 
-    exposure_time_map = aa.Array.ones(shape_2d=(2, 2))
+    exposure_time_map = aa.Array.ones(shape_2d=(2, 2), pixel_scales=1.0)
     data_with_poisson_noise = aa.preprocess.data_eps_with_poisson_noise_added(
         data_eps=data, exposure_time_map=exposure_time_map, seed=1
     )
 
     assert (data_with_poisson_noise.in_2d == np.array([[11, 14], [13, 11]])).all()
 
-    data = aa.Array.manual_2d([[10000000.0, 0.0], [0.0, 10000000.0]])
+    data = aa.Array.manual_2d(
+        array=[[10000000.0, 0.0], [0.0, 10000000.0]], pixel_scales=1.0
+    )
 
-    exposure_time_map = aa.Array.ones(shape_2d=(2, 2))
+    exposure_time_map = aa.Array.ones(shape_2d=(2, 2), pixel_scales=1.0)
 
     data_with_poisson_noise = aa.preprocess.data_eps_with_poisson_noise_added(
         data_eps=data, exposure_time_map=exposure_time_map, seed=1
@@ -509,7 +547,7 @@ def test__gaussian_noise_from_shape_and_sigma():
 
 def test__data_with_gaussian_noise_added():
 
-    data = aa.Array.ones(shape_2d=(3, 3))
+    data = aa.Array.ones(shape_2d=(3, 3), pixel_scales=1.0)
 
     data_with_noise = aa.preprocess.data_with_gaussian_noise_added(
         data=data, sigma=0.0, seed=1
