@@ -109,7 +109,7 @@ class TestVisibilities:
 
 
 class TestVisibilitiesNoiseMap:
-    def test__visibilities_noise_has_weight_operator(self):
+    def test__visibilities_noise_has_attributes(self):
 
         noise_map = aa.VisibilitiesNoiseMap.manual_1d(
             visibilities=[[1.0, 2.0], [3.0, 4.0]]
@@ -125,6 +125,9 @@ class TestVisibilitiesNoiseMap:
         assert noise_map.phases == pytest.approx(
             np.array([1.10714872, 0.92729522]), 1.0e-4
         )
+        assert noise_map.preconditioner_noise_normalization == pytest.approx(
+            1.4236, 1.0e-4
+        )
         assert (
             noise_map.Wop.todense()
             == np.array([[0.2 - 0.4j, 0.0 + 0.0j], [0.0 + 0.0j, 0.12 - 0.16j]])
