@@ -1,5 +1,3 @@
-from autoarray.mask import mask as msk
-from autoarray.structures import arrays
 from autoarray import util
 
 import os
@@ -555,8 +553,8 @@ class Test2dIndexesfrom1dIndex:
 
         indexes_1d = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
 
-        index_2d_for_index_1d = util.array.index_2d_for_index_1d_from_shape(
-            indexes_1d=indexes_1d, shape=(3, 3)
+        index_2d_for_index_1d = util.array.index_2d_for_index_1d_from(
+            indexes_1d=indexes_1d, shape_2d=(3, 3)
         )
 
         assert (
@@ -570,8 +568,8 @@ class Test2dIndexesfrom1dIndex:
 
         indexes_1d = np.array([0, 1, 2, 3, 4, 5])
 
-        index_2d_for_index_1d = util.array.index_2d_for_index_1d_from_shape(
-            indexes_1d=indexes_1d, shape=(2, 3)
+        index_2d_for_index_1d = util.array.index_2d_for_index_1d_from(
+            indexes_1d=indexes_1d, shape_2d=(2, 3)
         )
 
         assert (
@@ -583,8 +581,8 @@ class Test2dIndexesfrom1dIndex:
 
         indexes_1d = np.array([0, 1, 2, 3, 4, 5])
 
-        indexes_2d = util.array.index_2d_for_index_1d_from_shape(
-            indexes_1d=indexes_1d, shape=(3, 2)
+        indexes_2d = util.array.index_2d_for_index_1d_from(
+            indexes_1d=indexes_1d, shape_2d=(3, 2)
         )
 
         assert (
@@ -595,8 +593,8 @@ class Test2dIndexesfrom1dIndex:
 
         indexes_1d = np.array([1, 4, 7, 8, 0, 2, 3, 5, 6])
 
-        index_2d_for_index_1d = util.array.index_2d_for_index_1d_from_shape(
-            indexes_1d=indexes_1d, shape=(3, 3)
+        index_2d_for_index_1d = util.array.index_2d_for_index_1d_from(
+            indexes_1d=indexes_1d, shape_2d=(3, 3)
         )
 
         assert (
@@ -614,8 +612,8 @@ class Test1dIndexFromIndex2D:
             [[0, 0], [0, 1], [0, 2], [1, 0], [1, 1], [1, 2], [2, 0], [2, 1], [2, 2]]
         )
 
-        index_1d_for_index_2d = util.array.index_1d_for_index_2d_from_shape(
-            indexes_2d=indexes_2d, shape=(3, 3)
+        index_1d_for_index_2d = util.array.index_1d_for_index_2d_from(
+            indexes_2d=indexes_2d, shape_2d=(3, 3)
         )
 
         assert (index_1d_for_index_2d == np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])).all()
@@ -624,8 +622,8 @@ class Test1dIndexFromIndex2D:
 
         indexes_2d = np.array([[0, 0], [0, 1], [0, 2], [1, 0], [1, 1], [1, 2]])
 
-        index_1d_for_index_2d = util.array.index_1d_for_index_2d_from_shape(
-            indexes_2d=indexes_2d, shape=(2, 3)
+        index_1d_for_index_2d = util.array.index_1d_for_index_2d_from(
+            indexes_2d=indexes_2d, shape_2d=(2, 3)
         )
 
         assert (index_1d_for_index_2d == np.array([0, 1, 2, 3, 4, 5])).all()
@@ -634,8 +632,8 @@ class Test1dIndexFromIndex2D:
 
         indexes_2d = np.array([[0, 0], [0, 1], [1, 0], [1, 1], [2, 0], [2, 1]])
 
-        index_1d_for_index_2d = util.array.index_1d_for_index_2d_from_shape(
-            indexes_2d=indexes_2d, shape=(3, 2)
+        index_1d_for_index_2d = util.array.index_1d_for_index_2d_from(
+            indexes_2d=indexes_2d, shape_2d=(3, 2)
         )
 
         assert (index_1d_for_index_2d == np.array([0, 1, 2, 3, 4, 5])).all()
@@ -646,8 +644,8 @@ class Test1dIndexFromIndex2D:
             [[0, 1], [1, 1], [2, 1], [2, 2], [0, 0], [0, 2], [1, 0], [1, 2], [2, 0]]
         )
 
-        index_1d_for_index_2d = util.array.index_1d_for_index_2d_from_shape(
-            indexes_2d=indexes_2d, shape=(3, 3)
+        index_1d_for_index_2d = util.array.index_1d_for_index_2d_from(
+            indexes_2d=indexes_2d, shape_2d=(3, 3)
         )
 
         assert (index_1d_for_index_2d == np.array([1, 4, 7, 8, 0, 2, 3, 5, 6])).all()
@@ -660,7 +658,7 @@ class TestArray1DFromArray2d:
 
         mask = np.array([[True, True, True], [True, False, True], [True, True, True]])
 
-        array_1d = util.array.sub_array_1d_from_sub_array_2d(
+        array_1d = util.array.sub_array_1d_from(
             mask=mask, sub_array_2d=array_2d, sub_size=1
         )
 
@@ -672,7 +670,7 @@ class TestArray1DFromArray2d:
             [[True, False, True], [False, False, False], [True, False, True]]
         )
 
-        array_1d = util.array.sub_array_1d_from_sub_array_2d(
+        array_1d = util.array.sub_array_1d_from(
             mask=mask, sub_array_2d=array_2d, sub_size=1
         )
 
@@ -688,7 +686,7 @@ class TestArray1DFromArray2d:
             ]
         )
 
-        array_1d = util.array.sub_array_1d_from_sub_array_2d(
+        array_1d = util.array.sub_array_1d_from(
             mask=mask, sub_array_2d=array_2d, sub_size=1
         )
 
@@ -705,7 +703,7 @@ class TestArray1DFromArray2d:
             ]
         )
 
-        array_1d = util.array.sub_array_1d_from_sub_array_2d(
+        array_1d = util.array.sub_array_1d_from(
             mask=mask, sub_array_2d=array_2d, sub_size=1
         )
 
@@ -726,7 +724,7 @@ class TestArray1DFromArray2d:
 
         mask = np.array([[True, True, True], [True, False, True], [True, True, True]])
 
-        sub_array_1d = util.array.sub_array_1d_from_sub_array_2d(
+        sub_array_1d = util.array.sub_array_1d_from(
             sub_array_2d=sub_array_2d, mask=mask, sub_size=2
         )
 
@@ -734,7 +732,7 @@ class TestArray1DFromArray2d:
 
         mask = np.array([[True, False, True], [True, False, True], [True, True, False]])
 
-        sub_array_1d = util.array.sub_array_1d_from_sub_array_2d(
+        sub_array_1d = util.array.sub_array_1d_from(
             sub_array_2d=sub_array_2d, mask=mask, sub_size=2
         )
 
@@ -761,7 +759,7 @@ class TestArray1DFromArray2d:
             ]
         )
 
-        sub_array_1d = util.array.sub_array_1d_from_sub_array_2d(
+        sub_array_1d = util.array.sub_array_1d_from(
             sub_array_2d=sub_array_2d, mask=mask, sub_size=2
         )
 
@@ -819,7 +817,7 @@ class TestArray1DFromArray2d:
             ]
         )
 
-        sub_array_1d = util.array.sub_array_1d_from_sub_array_2d(
+        sub_array_1d = util.array.sub_array_1d_from(
             sub_array_2d=sub_array_2d, mask=mask, sub_size=2
         )
 
@@ -845,7 +843,7 @@ class TestArray1DFromArray2d:
 
         mask = np.array([[False, True], [True, False]])
 
-        sub_array_1d = util.array.sub_array_1d_from_sub_array_2d(
+        sub_array_1d = util.array.sub_array_1d_from(
             sub_array_2d=sub_array_2d, mask=mask, sub_size=3
         )
 
@@ -854,6 +852,24 @@ class TestArray1DFromArray2d:
             == np.array([1, 2, 3, 7, 8, 9, 13, 14, 15, 4, 5, 6, 10, 11, 12, 16, 17, 18])
         ).all()
 
+    def test__sub_array_1d_complex__sub_size_1(self):
+
+        array_2d = np.array(
+            [
+                [1 + 1j, 2 + 2j, 3 + 3],
+                [4 + 4j, 5 + 5j, 6 + 6j],
+                [7 + 7j, 8 + 8j, 9 + 9j],
+            ]
+        )
+
+        mask = np.array([[True, True, True], [True, False, True], [True, True, True]])
+
+        array_1d = util.array.sub_array_complex_1d_from(
+            mask=mask, sub_array_2d=array_2d, sub_size=1
+        )
+
+        assert (array_1d == np.array([5 + 5j])).all()
+
 
 class TestArray2dForArray1d:
     def test__simple_2d_array__is_masked_and_mapped__sub_size_1(self):
@@ -862,7 +878,7 @@ class TestArray2dForArray1d:
 
         mask = np.full(fill_value=False, shape=(2, 2))
 
-        array_2d = util.array.sub_array_2d_from_sub_array_1d(
+        array_2d = util.array.sub_array_2d_from(
             sub_array_1d=array_1d, mask=mask, sub_size=1
         )
 
@@ -872,7 +888,7 @@ class TestArray2dForArray1d:
 
         mask = np.array([[False, False], [False, True]])
 
-        array_2d = util.array.sub_array_2d_from_sub_array_1d(
+        array_2d = util.array.sub_array_2d_from(
             sub_array_1d=array_1d, mask=mask, sub_size=1
         )
 
@@ -888,7 +904,7 @@ class TestArray2dForArray1d:
             ]
         )
 
-        array_2d = util.array.sub_array_2d_from_sub_array_1d(
+        array_2d = util.array.sub_array_2d_from(
             sub_array_1d=array_1d, mask=mask, sub_size=1
         )
 
@@ -907,7 +923,7 @@ class TestArray2dForArray1d:
 
         mask = np.array([[False, False], [False, True]])
 
-        array_2d = util.array.sub_array_2d_from_sub_array_1d(
+        array_2d = util.array.sub_array_2d_from(
             sub_array_1d=array_1d, mask=mask, sub_size=2
         )
 
@@ -923,338 +939,20 @@ class TestArray2dForArray1d:
             )
         ).all()
 
+    def test__simple_2d_complex_array__is_masked_and_mapped__sub_size_1(self):
 
-class TestPeakPixels:
-    def test__simple_arrays(self):
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 1.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-            ]
+        array_1d = np.array(
+            [1.0 + 1j, 2.0 + 2j, 3.0 + 3j, 4.0 + 4j], dtype="complex128"
         )
 
-        peak_pixels = util.array.peak_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert peak_pixels == [[2, 2]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 1.0, 0.0, 1.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-            ]
+        array_2d = util.array.sub_array_complex_2d_via_sub_indexes_from(
+            sub_array_1d=array_1d,
+            sub_shape_2d=(2, 2),
+            sub_mask_index_for_sub_mask_1d_index=np.array(
+                [[0, 0], [0, 1], [1, 0], [1, 1]], dtype="int"
+            ),
         )
 
-        peak_pixels = util.array.peak_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert peak_pixels == [[2, 1], [2, 3]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 1.0, 0.0],
-                [0.0, 1.0, 0.0, 1.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-            ]
-        )
-
-        peak_pixels = util.array.peak_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert peak_pixels == [[2, 1]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 2.0, 0.0],
-                [0.0, 1.0, 0.0, 1.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-            ]
-        )
-
-        peak_pixels = util.array.peak_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert peak_pixels == [[1, 3], [2, 1]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [0.0, 0.0, 7.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [4.0, 1.0, 0.0, 1.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 8.0, 0.0, 0.0],
-            ]
-        )
-
-        peak_pixels = util.array.peak_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert peak_pixels == [[2, 3]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [2.0, 8.0, 7.0, 6.0, 8.0],
-                [4.0, 9.0, 4.0, 1.0, 8.0],
-                [1.0, 0.5, 7.0, 9.0, 8.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-            ]
-        )
-
-        peak_pixels = util.array.peak_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert peak_pixels == [[2, 1], [3, 3]]
-
-    def test__simple_arrays_with_mask(self):
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 1.0, 0.0, 1.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-            ]
-        )
-
-        mask_2d = msk.Mask.manual(
-            mask_2d=[
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, False, True],
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-            ]
-        )
-
-        peak_pixels = util.array.peak_pixels_from_array_2d(
-            array_2d=array.in_2d, mask_2d=mask_2d
-        )
-
-        assert peak_pixels == [[2, 3]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 1.0, 0.0],
-                [0.0, 1.0, 0.0, 1.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-            ]
-        )
-
-        mask_2d = msk.Mask.manual(
-            mask_2d=[
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-            ]
-        )
-
-        peak_pixels = util.array.peak_pixels_from_array_2d(
-            array_2d=array.in_2d, mask_2d=mask_2d
-        )
-
-        assert peak_pixels == []
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-                [2.0, 8.0, 7.0, 6.0, 8.0],
-                [4.0, 9.0, 4.0, 1.0, 8.0],
-                [1.0, 0.5, 7.0, 9.0, 8.0],
-                [0.0, 0.0, 0.0, 0.0, 0.0],
-            ]
-        )
-
-        mask_2d = msk.Mask.manual(
-            mask_2d=[
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, False, True],
-                [True, True, True, True, True],
-            ]
-        )
-
-        peak_pixels = util.array.peak_pixels_from_array_2d(
-            array_2d=array.in_2d, mask_2d=mask_2d
-        )
-
-        assert peak_pixels == [[3, 3]]
-
-
-class TestTroughPixels:
-    def test__simple_arrays(self):
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 1.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-            ]
-        )
-
-        trough_pixels = util.array.trough_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert trough_pixels == [[2, 2]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 1.0, 9.0, 1.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-            ]
-        )
-
-        trough_pixels = util.array.trough_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert trough_pixels == [[2, 1], [2, 3]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 1.0, 9.0],
-                [9.0, 1.0, 9.0, 1.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-            ]
-        )
-
-        trough_pixels = util.array.trough_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert trough_pixels == [[2, 1]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 1.0, 9.0],
-                [9.0, 1.0, 9.0, 2.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-            ]
-        )
-
-        trough_pixels = util.array.trough_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert trough_pixels == [[1, 3], [2, 1]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [9.0, 9.0, 7.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [4.0, 1.0, 9.0, 1.0, 9.0],
-                [9.0, 1.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 8.0, 9.0, 9.0],
-            ]
-        )
-
-        trough_pixels = util.array.trough_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert trough_pixels == [[2, 3]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [2.0, 8.0, 7.0, 6.0, 8.0],
-                [4.0, 0.1, 4.0, 1.0, 8.0],
-                [1.0, 0.5, 7.0, 0.1, 8.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-            ]
-        )
-
-        trough_pixels = util.array.trough_pixels_from_array_2d(array_2d=array.in_2d)
-
-        assert trough_pixels == [[2, 1], [3, 3]]
-
-    def test__simple_arrays_with_mask(self):
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 1.0, 9.0, 1.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-            ]
-        )
-
-        mask_2d = msk.Mask.manual(
-            mask_2d=[
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, False, True],
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-            ]
-        )
-
-        trough_pixels = util.array.trough_pixels_from_array_2d(
-            array_2d=array.in_2d, mask_2d=mask_2d
-        )
-
-        assert trough_pixels == [[2, 3]]
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 1.0, 9.0],
-                [9.0, 1.0, 9.0, 1.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-            ]
-        )
-
-        mask_2d = msk.Mask.manual(
-            mask_2d=[
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-            ]
-        )
-
-        trough_pixels = util.array.trough_pixels_from_array_2d(
-            array_2d=array.in_2d, mask_2d=mask_2d
-        )
-
-        assert trough_pixels == []
-
-        array = arrays.Array.manual_2d(
-            array=[
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-                [2.0, 8.0, 7.0, 6.0, 8.0],
-                [4.0, 9.0, 4.0, 1.0, 8.0],
-                [1.0, 0.5, 7.0, 0.1, 8.0],
-                [9.0, 9.0, 9.0, 9.0, 9.0],
-            ]
-        )
-
-        mask_2d = msk.Mask.manual(
-            mask_2d=[
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, True, True],
-                [True, True, True, False, True],
-                [True, True, True, True, True],
-            ]
-        )
-
-        trough_pixels = util.array.trough_pixels_from_array_2d(
-            array_2d=array.in_2d, mask_2d=mask_2d
-        )
-
-        assert trough_pixels == [[3, 3]]
+        assert (
+            array_2d == np.array([[1.0 + 1j, 2.0 + 2j], [3.0 + 3j, 4.0 + 4j]])
+        ).all()
